---
title: "Making Incense: A Cursory Guide"
description: A quick how-to on making Japanese style incense.
date: 2024-12-16
tags:
  - Incense
  - Incense Making
synopsis: A quick how-to on making Japanese style incense.
imageURL: /img/siftinsagesquare.webp
imageAlt: A sieve containing fluffy ground green sage beside a small pile of fine green powder.
mastodon_id: "113666537272260557"
---
While I like to post incense builds, I haven't yet posted on exactly how to go about turning raw ingredients into Japanese style incense sticks. Here's a 1,000 mile overview of the process to accompany a video I recently uploaded to my new PeerTube instance on that very topic. For more info, you can check out [IncenseDragon](https://www.youtube.com/c/IncenseDragon) on YouTube, read this [very useful article](https://blog.rauchfahne.de/en/2023/02/19/making-your-own-incense-sticks-basic-knowledge-and-useful-information/) by Irene of Rauchfahne.de, peruse [incensemaking.com](https://incensemaking.com), and look through some [posts flaired with "incense making"](https://www.reddit.com/r/Incense/?f=flair_name%3A%22Incense%20Making%22) on the [incense subreddit](https://reddit.com/r/incense). Making incense is a difficult, involved process, and this is only a shallow overview; I highly recommend looking through these resources for more in-depth information.

<figure><div style="position: relative; padding-top: 56.25%;"><iframe title="Japanese Style Incense Making Process" width="100%" height="100%" src="https://makertube.net/videos/embed/8864549d-204b-4f48-884e-ca912cf4235c" frameborder="0" allowfullscreen="" sandbox="allow-same-origin allow-scripts allow-popups allow-forms" style="position: absolute; inset: 0px;"></iframe></div><figcaption>More or less the full process of making incense. It didn't go perfectly, but I think it's important to show that too. This is also the first time I've attempted to make a video like this; making incense is hard as is, let alone while trying to film the process!</figcaption></figure>

## What you'll need: the bare minimum
1. A scale
2. A mortar and pestle
3. A 140 mesh sieve
4. An extruder
5. A drying screen
6. A respirator

### A scale
If you can, get something quite fine, like a milligram scale. This will help you make very small test batches before you commit to a build.

### A mortar and pestle
You can't get all your ingredients pre-powdered, so you're going to need something to crush resins and grind herbs. It's a labor intensive method, but it produces very little heat - perfect for delicate aromatics. At some point, you'll likely want to expand your grinding capabilities, especially if you want to grind your own woods, but that's a topic for another time.

### A 140 mesh sieve
100 microns seems to be the magic number for incense powders; ingredients reduced to this size perform better in terms of fragrance, and ease of extrusion. Your sticks will burn more slowly, and you'll be able to use less binder in the dough. Sieve carefully, allowing only the finest particles to pass through.

### An extruder
I use [one of these (not an affiliate link)](https://www.aliexpress.us/item/3256804509917099.html). There are many options available, but try to find an extruder that gradually comes to a point rather than one that takes interchangeable plates - they'll produce rough sticks. Also avoid anything made of plastic; I promise you it won't be strong enough.

### A drying screen
Again, there are many options, some of which you may have already laying around. I use [one of these (also not an affiliate link)](https://www.aliexpress.us/item/3256806230786054.html).

### A respirator
I almost forgot to mention this, but [as Irene points out](https://blog.rauchfahne.de/en/2023/02/19/making-your-own-incense-sticks-basic-knowledge-and-useful-information/) this is an important piece. Inhaling fine powders of any kind is very very bad for you. Don't mess about with this one: use a proper respirator, or at least a well-fitted n95 mask.

## Coming up with a build
If you don't have a build / recipe to go by, it can be a challenge to work out what ingredients to use and in what proportions. While you can find builds in many places, eventually you're going to have to sit down and do some testing. Fundamentally, incense is comprised of three key components: base, binder, and aromatics. Some ingredients can occupy more than one of these categories. It's difficult to give even rough ratios for these components, because they will differ wildly with the specific ingredients used. What I recommend is combining ingredients in different ratios and burning them as a trail on a bed of ash, little by little. For instance, try burning a trail of 70% sandalwood and 30% frankincense. How does it burn; does it stay lit? Which fragrance is more prominent? Is it aromatic, or mostly smoky? How does this build change when 10% of the sandalwood is exchanged for lavender, or patchouli? Once you've got a fragrance you're happy with, incorporate some binder and try to burn again.

I could write extensively on this piece alone, but for now, here are some general rules to get you started:

* Herbs and flowers quickly become acrid unless used in low percentages. In [my Silver Tip build](../silvertip/), for example, I can only get away with 10% osmanthus flowers before my build begins to smell bad.
* Oily woods such as mid to high quality sandalwood, palo santo, and agarwood can be used at high percentages without smelling too smoky.
* Resins are good not only fragrant, but some can be used for binding and temperature regulation. Too much will prevent your sticks from burning, so work your way up slowly with resins.
* Less is more. It's always tempting to cram as much of an aromatic material into a stick as you can. Instead, try to see how little you can get away with for a more refined profile.
* Gum binders such as guar gum, xanthan gum, and tragacanth can be used at very low percentages — I've seen as low as 3%. Wood binders such as litsea glutinosa can require much larger percentages. After you've successfully incorporated a binder into the sample you used for a trail-burn test, try adding a drop or two of water and rolling a small stick by hand to see how the dough performs.

## Grinding
Possibly the most difficult aspect of incense making, the key to grinding quality powders is to keep things cool. Use electric grinders in short bursts, allowing ample time to cool, or use methods that generate less heat. Not only does heat release aromatics that you want to retain, resins get sticky. If using a mortar and pestle, it can help to freeze resins along with your mortar and pestle to keep from gumming up the works. It may be easiest to buy pre-powdered woods at first; while resins and herbs aren't especially difficult to powder at home, grinding wood is another beast altogether.

## Sieving
Sieve slowly and gently, being careful that only the finest particles pass through the screen. The best advice I can give here is to try to enjoy the time you spend sieving as best you can, because you're going to be spending a lot of time this way.

## Forming a dough
First thoroughly blend together your dry powdered ingredients, then add water with great trepidation while stirring until a dough begins to come together. As soon as you are able, knead this dough with your hands, adding water as necessary to form a smooth dough that doesn't crack when rolled into a ball. Too much water will result in a difficult extrusion and more warping during drying; too little will result in an even more difficult extrusion. Aim for the consistency of clay.

## Extrusion
Load the dough into your extruder, being very careful to avoid introducing any air bubbles. Carefully extrude the incense either onto a board, or directly onto your drying screen.

## Straightening and drying
Trim your sticks into even lengths while wet, and gently roll them with either a board, or your fingers, until they are straight. Carefully lay them side by side on your drying screen, and place a board against the length of the sticks to prevent too much horizontal warping as they dry. Cover the sticks with another board to prevent vertical warping, and allow the sticks to dry slowly over the course of a day or two.

## Curing
Although your incense may appear dry, it can take some time for much of the moisture to work its way out. Ingredients also benefit from time for the aromatics to settle and meld together into a cohesive composition. Give your sticks a couple of weeks before you judge them too harshly; you may notice changes in fragrance for up to a year.

## Conclusion
This is how I make my sticks, which I extrude to ~2mm and about 10" long to be broken into 5" lengths after drying. Hopefully, any builds I post here ought to work when extruded to this size in the way I have described; all sorts of factors affect incense fragrance and its ability to burn, so I can't make any guarantees as to how your incense will turn out if you follow one of my builds for a different extrusion diameter.

Incense making is a dying art even in cultures with strong incense traditions; it's a laborious exercise that requires extensive trial and error, but the results can be beautiful in ways that no other art-form can emulate. Unfortunately, incense makers tend to be opaque with their practices, and information is scarce in the English speaking world, so it is my hope that this guide can be a useful launching point for someone wishing to start down the fragrant path.
